==> jc-1.4.0.tar.gz: gnu/classpath/ServiceProviderLoadingAction.h <==
// final class gnu.classpath.ServiceProviderLoadingAction

// class file dependencies
// @dep_class cbf8f6bed5683fe7 gnu_classpath_ServiceProviderLoadingAction
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_classpath_ServiceProviderLoadingAction_H_
#define _JC_gnu_classpath_ServiceProviderLoadingAction_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_classpath_ServiceProviderLoadingAction$sub_refs	_jc_gnu_classpath_ServiceProviderLoadingAction$sub_refs;
typedef struct _jc_gnu_classpath_ServiceProviderLoadingAction$sub_nonrefs	_jc_gnu_classpath_ServiceProviderLoadingAction$sub_nonrefs;
typedef struct _jc_gnu_classpath_ServiceProviderLoadingAction$refs	_jc_gnu_classpath_ServiceProviderLoadingAction$refs;
typedef struct _jc_gnu_classpath_ServiceProviderLoadingAction$nonrefs	_jc_gnu_classpath_ServiceProviderLoadingAction$nonrefs;
typedef struct _jc_gnu_classpath_ServiceProviderLoadingAction$object	_jc_gnu_classpath_ServiceProviderLoadingAction$object;

typedef const struct _jc_gnu_classpath_ServiceProviderLoadingAction$vmethods	_jc_gnu_classpath_ServiceProviderLoadingAction$vmethods;
typedef const struct _jc_gnu_classpath_ServiceProviderLoadingAction$vtable	_jc_gnu_classpath_ServiceProviderLoadingAction$vtable;
typedef const struct _jc_gnu_classpath_ServiceProviderLoadingAction$vtype	_jc_gnu_classpath_ServiceProviderLoadingAction$vtype;

// Constructors
extern void _jc_gnu_classpath_ServiceProviderLoadingAction$method$_init$af1671df28dd39ae(_jc_env *, struct _jc_gnu_classpath_ServiceProviderLoadingAction$object *, struct _jc_java_lang_Class$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_ClassLoader$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_classpath_ServiceProviderLoadingAction$method$run$b190d7b16d5785b8(_jc_env *, struct _jc_gnu_classpath_ServiceProviderLoadingAction$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_classpath_ServiceProviderLoadingAction$method_info$run$b190d7b16d5785b8;

// Virtual methods structure
struct _jc_gnu_classpath_ServiceProviderLoadingAction$vmethods {
	struct _jc_java_lang_Object$object	*(*run$b190d7b16d5785b8)(_jc_env *, struct _jc_gnu_classpath_ServiceProviderLoadingAction$object *);
};

// Vtable
struct _jc_gnu_classpath_ServiceProviderLoadingAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_classpath_ServiceProviderLoadingAction$vmethods	gnu_classpath_ServiceProviderLoadingAction;
};

// Vtype
struct _jc_gnu_classpath_ServiceProviderLoadingAction$vtype {
	_jc_type			type;
	_jc_gnu_classpath_ServiceProviderLoadingAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_classpath_ServiceProviderLoadingAction$sub_refs {
	struct _jc_java_lang_Class$object	*spi;
	struct _jc_java_lang_String$object	*providerName;
	struct _jc_java_lang_ClassLoader$object	*loader;
};

// Reference instance fields (object)
struct _jc_gnu_classpath_ServiceProviderLoadingAction$refs {
    _jc_gnu_classpath_ServiceProviderLoadingAction$sub_refs	gnu_classpath_ServiceProviderLoadingAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_classpath_ServiceProviderLoadingAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_classpath_ServiceProviderLoadingAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_classpath_ServiceProviderLoadingAction$sub_nonrefs	gnu_classpath_ServiceProviderLoadingAction;
};

// Object instance structure
struct _jc_gnu_classpath_ServiceProviderLoadingAction$object {
	_jc_gnu_classpath_ServiceProviderLoadingAction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_classpath_ServiceProviderLoadingAction$vtype	*vtype;
	_jc_gnu_classpath_ServiceProviderLoadingAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_classpath_ServiceProviderLoadingAction$vtype _jc_gnu_classpath_ServiceProviderLoadingAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_classpath_ServiceProviderLoadingAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_classpath_ServiceProviderLoadingAction$class_object;

#endif	/* _JC_gnu_classpath_ServiceProviderLoadingAction_H_ */

==> jc-1.4.6.tar.gz: gnu/classpath/ServiceProviderLoadingAction.h <==
// final class gnu.classpath.ServiceProviderLoadingAction

// class file dependencies
// @dep_class cbf8f6bed5683fe7 gnu_classpath_ServiceProviderLoadingAction
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_classpath_ServiceProviderLoadingAction_H_
#define _JC_gnu_classpath_ServiceProviderLoadingAction_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_classpath_ServiceProviderLoadingAction$sub_refs	_jc_gnu_classpath_ServiceProviderLoadingAction$sub_refs;
typedef struct _jc_gnu_classpath_ServiceProviderLoadingAction$sub_nonrefs	_jc_gnu_classpath_ServiceProviderLoadingAction$sub_nonrefs;
typedef struct _jc_gnu_classpath_ServiceProviderLoadingAction$refs	_jc_gnu_classpath_ServiceProviderLoadingAction$refs;
typedef struct _jc_gnu_classpath_ServiceProviderLoadingAction$nonrefs	_jc_gnu_classpath_ServiceProviderLoadingAction$nonrefs;
typedef struct _jc_gnu_classpath_ServiceProviderLoadingAction$object	_jc_gnu_classpath_ServiceProviderLoadingAction$object;

typedef const struct _jc_gnu_classpath_ServiceProviderLoadingAction$vmethods	_jc_gnu_classpath_ServiceProviderLoadingAction$vmethods;
typedef const struct _jc_gnu_classpath_ServiceProviderLoadingAction$vtable	_jc_gnu_classpath_ServiceProviderLoadingAction$vtable;
typedef const struct _jc_gnu_classpath_ServiceProviderLoadingAction$vtype	_jc_gnu_classpath_ServiceProviderLoadingAction$vtype;

// Constructors
extern void _jc_gnu_classpath_ServiceProviderLoadingAction$method$_init$af1671df28dd39ae(_jc_env *, struct _jc_gnu_classpath_ServiceProviderLoadingAction$object *, struct _jc_java_lang_Class$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_ClassLoader$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_classpath_ServiceProviderLoadingAction$method$run$b190d7b16d5785b8(_jc_env *, struct _jc_gnu_classpath_ServiceProviderLoadingAction$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_classpath_ServiceProviderLoadingAction$method_info$run$b190d7b16d5785b8;

// Virtual methods structure
struct _jc_gnu_classpath_ServiceProviderLoadingAction$vmethods {
	struct _jc_java_lang_Object$object	*(*run$b190d7b16d5785b8)(_jc_env *, struct _jc_gnu_classpath_ServiceProviderLoadingAction$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_classpath_ServiceProviderLoadingAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_classpath_ServiceProviderLoadingAction$vmethods	gnu_classpath_ServiceProviderLoadingAction;
};

// Vtype
struct _jc_gnu_classpath_ServiceProviderLoadingAction$vtype {
	_jc_type			type;
	_jc_gnu_classpath_ServiceProviderLoadingAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_classpath_ServiceProviderLoadingAction$sub_refs {
	struct _jc_java_lang_Class$object	*spi;
	struct _jc_java_lang_String$object	*providerName;
	struct _jc_java_lang_ClassLoader$object	*loader;
};

// Reference instance fields (object)
struct _jc_gnu_classpath_ServiceProviderLoadingAction$refs {
    _jc_gnu_classpath_ServiceProviderLoadingAction$sub_refs	gnu_classpath_ServiceProviderLoadingAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_classpath_ServiceProviderLoadingAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_classpath_ServiceProviderLoadingAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_classpath_ServiceProviderLoadingAction$sub_nonrefs	gnu_classpath_ServiceProviderLoadingAction;
};

// Object instance structure
struct _jc_gnu_classpath_ServiceProviderLoadingAction$object {
	_jc_gnu_classpath_ServiceProviderLoadingAction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_classpath_ServiceProviderLoadingAction$vtype	*vtype;
	_jc_gnu_classpath_ServiceProviderLoadingAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_classpath_ServiceProviderLoadingAction$vtype _jc_gnu_classpath_ServiceProviderLoadingAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_classpath_ServiceProviderLoadingAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_classpath_ServiceProviderLoadingAction$class_object;

#endif	/* _JC_gnu_classpath_ServiceProviderLoadingAction_H_ */
